@@ -350,7 +350,7 @@ def storeImagesLocally(context,
         # right, traverse to image
         try:
             imageObj = portal.unrestrictedTraverse(img_path)
-        except (KeyError, AttributeError):
+        except (KeyError, AttributeError, NotFound):
             # wrong img_path
             logger.warning(
                 'In \'storeImagesLocally\', could not traverse '
@@ -371,7 +371,7 @@ def storeImagesLocally(context,
         # right, we have an external image, download it, stores it in context and update img_src
         try:
             downloaded_img_path, downloaded_img_infos = urllib.urlretrieve(img_src)
-        except IOError:
+        except (IOError, UnicodeError):
             # url not existing
             return None, None
 
@@ -482,6 +482,43 @@ def storeImagesLocally(context,
                                        method='html') for x in tree.iterchildren()])
 
 
+def separate_images(xhtmlContent, pretty_print=False):
+    """Make sure images are separated in different paragraphs.
+       So <p><img .../><img .../></p> is changed to
+       <p><img .../></p></p><img .../></p>."""
+
+    tree = _turnToLxmlTree(xhtmlContent)
+    if not isinstance(tree, lxml.html.HtmlElement):
+        return xhtmlContent
+
+    # return received xhtmlContent if nothing was changed
+    changed = False
+    inserted_index = 1
+    for elt_index, elt in enumerate(tree.getchildren()):
+        if elt.tag not in ('p', 'div'):
+            continue
+        # only manage <p>/<div> containing several <img>, nothing else
+        imgs = elt.xpath('.//img')
+        len_imgs = len(imgs)
+        contained_tags = elt.getchildren()
+        if len_imgs > 1 and len_imgs == len(contained_tags) and not elt.text_content():
+            changed = True
+            for img_index, img in enumerate(imgs[1:]):
+                new_elt = lxml.html.Element(elt.tag)
+                tree.insert(elt_index + inserted_index + img_index, new_elt)
+                inserted_index += 1
+                # append will move the img, not necessary to remove from elt
+                new_elt.append(img)
+
+    if not changed:
+        return xhtmlContent
+
+    return ''.join([lxml.html.tostring(x,
+                                       encoding='utf-8',
+                                       pretty_print=pretty_print,
+                                       method='html') for x in tree.iterchildren()])
+
+
 def object_link(obj, view='view', attribute='Title', content=''):
     """ Returns an html link for the given object """
     href = view and "%s/%s" % (obj.absolute_url(), view) or obj.absolute_url()
